HTTP_HEADERS = (
    "Accept",
    "Accept-Language",
    "Authorization",
    "Content-Language",
    "Content-Type",
    "DPR",
    "Downlink",
    "Origin",
    "Save-Data",
    "Viewport-Width",
    "Width",
    "X-AUTH-TOKEN",
    "X-CSRF-TOKEN",
    "X-REQUESTED-WITH",
    "X-Auth-Token",
    "X-Csrf-Token",
    "X-Requested-With",
    "x-Auth-Token",
    "x-Csrf-Token",
    "x-Requested-With",
    "x-auth-token",
    "x-csrf-token",
    "x-requested-with",
)
